summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/ownedhierarchicalcodeblock.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
commit99a2774ca6f1cab334de5d43fe36fc44ae889a4c (patch)
treeeff34cf0762227f6baf2a93e8fef48d4bed2651c /umbrello/umbrello/ownedhierarchicalcodeblock.h
parent1c104292188541106338d4940b0f04beeb4301a0 (diff)
downloadtdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.tar.gz
tdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.zip
TQt4 convert kdesdk
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1236185 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/ownedhierarchicalcodeblock.h')
-rw-r--r--umbrello/umbrello/ownedhierarchicalcodeblock.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/umbrello/umbrello/ownedhierarchicalcodeblock.h b/umbrello/umbrello/ownedhierarchicalcodeblock.h
index 04717381..7a99fe65 100644
--- a/umbrello/umbrello/ownedhierarchicalcodeblock.h
+++ b/umbrello/umbrello/ownedhierarchicalcodeblock.h
@@ -30,6 +30,7 @@ class CodeDocument;
class OwnedHierarchicalCodeBlock : public HierarchicalCodeBlock, public OwnedCodeBlock
{
Q_OBJECT
+ TQ_OBJECT
public:
// Constructors/Destructors
@@ -38,7 +39,7 @@ public:
/** constructor with TQString so we can create & populate it in
* one step.
*/
- OwnedHierarchicalCodeBlock ( UMLObject * parent, CodeDocument * parentDoc, const TQString &start="", const TQString &end="", const TQString &comment="" );
+ OwnedHierarchicalCodeBlock ( UMLObject * tqparent, CodeDocument * tqparentDoc, const TQString &start="", const TQString &end="", const TQString &comment="" );
/**
* Empty Destructor
@@ -48,7 +49,7 @@ public:
// Public attributes
//
// Return the parent code document
CodeDocument * getParentDocument();
// these next 2 methods should be supplied by inheriting classes
@@ -48,7 +49,7 @@ public:
// Public attributes
//
- // Return the parent code document
+ // Return the tqparent code document
CodeDocument * getParentDocument();
// these next 2 methods should be supplied by inheriting classes